## START: Set by rpmautospec
## (rpmautospec version 0.6.0)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 1;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

# F41FailsToInstall: blender
# https://bugzilla.redhat.com/show_bug.cgi?id=2291492
%bcond blender 0
%bcond skimage 1

Name:           python-trimesh
Version:        4.4.8
Release:        %autorelease
Summary:        Import, export, process, analyze and view triangular meshes

# The entire source is (SPDX) MIT, except:
#   - trimesh/transformations.py is BSD-3-Clause
#   - trimesh/exchange/openctm.py is Zlib
# Additionally, the following are under the same (SPDX) MIT license as the
# overall source, but with a different copyright statement:
License:        MIT AND BSD-3-Clause AND Zlib
URL:            https://trimsh.org
Source:         https://github.com/mikedh/trimesh/archive/%{version}/trimesh-%{version}.tar.gz

# The combination of an arched package with only noarch binary packages makes
# it easier for us to detect arch-dependent test failures, since the tests will
# always be run on every platform, and easier for us to skip failing tests if
# necessary, since we can be sure that %%ifarch macros work as expected.
#
# Since the package still contains no compiled machine code, we still have no
# debuginfo.
%global debug_package %{nil}

# https://fedoraproject.org/wiki/Changes/EncourageI686LeafRemoval
ExcludeArch:    %{ix86}

# Turn off automatic python byte-compilation. One .py file,
# trimesh/resources/templates/blender_boolean.py, is actually a *template for a
# Python source* rather than an *actual Python source*, and trying to
# byte-compile it will break the build. We will byte-compile manually instead.
%undefine __brp_python_bytecompile

BuildRequires:  python3-devel
BuildRequires:  tomcli

# Run tests in parallel:
BuildRequires:  python3dist(pytest-xdist)

# Command-line tools that are (optional) test dependencies:
# tests/test_gltf.py
# Not yet packaged: https://github.com/KhronosGroup/glTF-Validator
#BuildRequires:  /usr/bin/gltf_validator

%global _description %{expand:
Trimesh is a pure Python library for loading and using triangular meshes with
an emphasis on watertight meshes. The goal of the library is to provide a fully
featured and well tested Trimesh object which allows for easy manipulation and
analysis, in the style of the Polygon object in the Shapely library.}

%description %{_description}


%package -n     python3-trimesh
Summary:        %{summary}
BuildArch:      noarch

Recommends:     python3-trimesh+easy = %{version}-%{release}
Recommends:     python3-trimesh+recommend = %{version}-%{release}

# The [recommends] extra was renamed to [recommend] for v4.
Obsoletes:      python3-trimesh+recommends < 4.0.0~~dev0-1
# In v4, the [all] extra became the same as [easy,recommend,test]. Since we
# don’t want to package the [test] extra, we no longer package [all]. If any
# package depends on it (unlikely), the dependency should be changed to
# [easy,recommend], and it should be suggested to upstream that this is really
# what they needed anyway.
Obsoletes:      python3-trimesh+all < 4.0.0~~dev0-1

# A number of external command-line executables provide optional functionality.
# We choose to make these weak dependencies (Recommends). Hints (Suggests)
# would also be justifiable—although it should be noted that dnf does not do
# anything with hints. Any weak dependencies should also be BuildRequires so
# that their satisfiability is verified at build time; some may also enable
# additional tests.
#
# trimesh.exchange.binvox
# Cannot be packaged (closed-source): https://www.patrickmin.com/binvox/
#BuildRequires:  /usr/bin/binvox
#Recommends:     /usr/bin/binvox
%if %{with blender}
# trimesh.interfaces.blender
BuildRequires:  /usr/bin/blender
Recommends:     /usr/bin/blender
%endif
# trimesh.graph
BuildRequires:  /usr/bin/dot
Recommends:     /usr/bin/dot
# trimesh.exchange.ply
%ifnarch s390x
# ExportTest.test_export fails with:
#   subprocess.CalledProcessError: Command '['/usr/bin/draco_encoder', '-qp',
#   '28', '-i', '/tmp/tmpd1uz557y.ply', '-o', '/tmp/tmpkbowi3es.drc']' died
#   with <Signals.SIGABRT: 6>.
# and stderr is:
#   terminate called after throwing an instance of 'std::bad_alloc'
#     what():  std::bad_alloc
# See also:
#   gtest failure on s390x
#   https://bugzilla.redhat.com/show_bug.cgi?id=2165173
# We conclude that draco is not necessarily usable on this platform.
BuildRequires:  /usr/bin/draco_decoder
Recommends:     /usr/bin/draco_decoder
BuildRequires:  /usr/bin/draco_encoder
Recommends:     /usr/bin/draco_encoder
%endif
# “openscad”: trimesh.interfaces.scad
# Library would also recognize “OpenSCAD”
BuildRequires:  /usr/bin/openscad
Recommends:     /usr/bin/openscad

# This probably should be in the [easy] extra but isn’t in the metadata at all;
# see README.rst and trimesh/ray/. However, it cannot be packaged until it
# supports the current version (3.x) of embree
# (https://github.com/scopatz/pyembree/issues/28).
#Recommends:     python3dist(pyembree)

%description -n python3-trimesh %{_description}


# We skip packaging the “deprecated” extra in F40 to avoid having to Obsolete
# it in F41, where the version of gmsh is too new.
%pyproject_extras_subpkg -n python3-trimesh -a easy
# Note that the "recommend" extra does have an arch-dependent dependency.
%pyproject_extras_subpkg -n python3-trimesh recommend


# We elect not to build a documentation package, for the following reasons:
#
#  1. A (relatively simple) patch is required to build them offline without
#     pip-installing requirements from PyPI.
#  2. The documentation includes notebooks translated to HTML from .ipynb
#     using nbconvert.
#      a. Some conversions fail (wholly or on a per-cell basis, if continuing
#         on errors is requested) in architecture-dependent ways. This means
#         that the contents of the documentation package would depend on the
#         builder architecture, and it could not be noarch—an undesirable
#         situation.
#      b. An “HTML-ified” notebook contains a blob of JavaScript and other
#         web assets that is exceptionally difficult (at best, tedious) to
#         account for under current bundling guidelines.
#  3. Sphinx-generated HTML documentation is not suitable for packaging in
#     general—see https://bugzilla.redhat.com/show_bug.cgi?id=2006555 for
#     discussion—and (because of the notebooks, if nothing else) the trimesh
#     documentation is not well-suited to building as a PDF instead of HTML.


%prep
%autosetup -n trimesh-%{version} -p1

# Stub out unavailable pyinstrument test dependency; we don’t really need to do
# profiling anyway. Note that this does mean that API function
# trimesh.viewer.windowed.SceneViewer(…) will not work with “profile=True”.
#
# Packaging pyinstrument would be difficult due to a vue.js-based HTML
# renderer. Since guidelines forbid pre-built minified or compiled JS or CSS,
# this would have to be patched out, or the web asset pipeline would have to be
# somehow executed in the RPM build environment. (Or, of course, we can
# continue to do without pyinstrument.)
mkdir -p _stub
cat > _stub/pyinstrument.py <<'EOF'
class Profiler(object):
    def __enter__(self, *args, **kwds):
        return self

    def __exit__(self, *args, **kwds):
        return False

    def output_text(self, *args, **kwds):
        return """
Profiling output would be here if pyinstrument were available.
"""

    def print(self, *args, **kwds):
        return self.output_text(*args, **kwds)
EOF

# Patch out unavailable dependencies from extras:
#
#   embreex: not packaged, https://github.com/mikedh/embreeX; this would
#            require version 2.x of embree, which was once available in a
#            compat package (https://src.fedoraproject.org/rpms/embree2) but
#            was retired; the current version was 4.x.
#   fast-simplification: not yet packaged,
#                        https://github.com/pyvista/fast-simplification; needs
#                        pyvista, https://github.com/pyvista/pyvista, to run
#                        the tests
#   glooey: not yet packaged, https://github.com/kxgames/glooey; needs fonts
#           that are not currently packaged unbundled from its assets
#   manifold3d: not yet packaged, https://github.com/elalish/manifold/
#   meshio: not yet packaged, https://github.com/nschloe/meshio,
#           https://bugzilla.redhat.com/show_bug.cgi?id=2283539
#   pyglet: incompatible version 2.x, beginning with F41. See “Path to
#           supporting Pyglet 2?” https://github.com/mikedh/trimesh/issues/2155
#   xatlas: not yet packaged, https://github.com/mworchel/xatlas-python;
#           depends on https://github.com/jpcy/xatlas, also not yet packaged
tomcli set pyproject.toml lists delitem --type regex --no-first \
    'project.optional-dependencies.easy' '(embreex|manifold3d|xatlas)\b.*'
tomcli set pyproject.toml lists delitem --type regex --no-first \
    'project.optional-dependencies.recommend' \
    '(fast-simplification|glooey|meshio)\b.*'
%ifarch s390x
# The python-cascadio package is currently ExcludeArch: s390x
# python-cascadio: Tests for cascadio fail on s390x, wrong endianness
# https://bugzilla.redhat.com/show_bug.cgi?id=2298452
tomcli set pyproject.toml lists delitem --type regex --no-first \
    'project.optional-dependencies.recommend' \
    '(cascadio)\b.*'
%endif
tomcli set pyproject.toml lists delitem --type regex --no-first \
    'project.optional-dependencies.recommend' 'pyglet\b.*'
%if %{without skimage}
tomcli set pyproject.toml lists delitem --type regex --no-first \
    'project.optional-dependencies.recommend' 'scikit-image\b.*'
%endif
# Those listed below are test-only dependencies: some are unavailable; the rest
# are unwanted under
# https://docs.fedoraproject.org/en-US/packaging-guidelines/Python/#_linters.
#
#   coveralls: linters/coverage/etc.
#   pyright: linters/coverage/etc.
#   pyinstrument: not packaged; see preceding “stub” patch
#   pytest-cov: linters/coverage/etc.
#   ruff: linters/coverage/etc.
#   pytest-beartype: linters/coverage/etc.
tomcli set pyproject.toml lists delitem --type regex --no-first \
    'project.optional-dependencies.test' \
    '(coveralls|py(instrument|right)|pytest-(beartype|cov)|ruff)\b.*'


%generate_buildrequires
# With v4, [all] = [easy,recommend,test,deprecated].
%pyproject_buildrequires -x easy,recommend,test


%build
%pyproject_wheel


%install
%pyproject_install
# Manual byte-compile, to skip that one troublesome “.py” template file:
find '%{buildroot}%{python3_sitelib}/trimesh' -type f \
    -name '*.py' ! -name 'blender_boolean.py' |
  while read -r pyfile
  do
    %py_byte_compile %{__python3} "${pyfile}"
  done
# Cannot handle skipping byte-compilation for blender_boolean.py:
#pyproject_save_files trimesh


%check
while read -r t
do
  k="${k-}${k+ and }not ($(sed -r 's/::/ and /' <<<"${t}"))"
done < <(sed -r '/^[[:blank:]]*($|#)/d' <<'EOF'
%ifnarch x86_64
# CacheTest.test_hash fails, or may fail, because xxhash is not faster than CRC
# and/or MD5.
#
# This is not as intended, and upstream might or might not care, but it’s only
# a performance defect, so we just skip the test here.
CacheTest::test_hash
%endif

%ifarch s390x
# Several test failures remain on s390x. For now, we choose to skip these tests
# rather than excluding the architecture, even though they certainly represent
# real defects.
#
# https://github.com/mikedh/trimesh/issues/1351
# https://github.com/mikedh/trimesh/files/7385479/test-failures.log
GLTFTest::test_export_custom_attributes
OBJTest::test_vertex_color
PermutateTest::test_permutate
PlyTest::test_face_attributes
PlyTest::test_uv_export
PlyTest::test_vertex_attributes
# Regressions in test_boolean.py with Blender 4.2.0
# https://github.com/mikedh/trimesh/issues/2267
# Fixed in trimesh 4.4.7, except on s390x:
# https://github.com/mikedh/trimesh/issues/2267#issuecomment-2302365583
BooleanTest::test_boolean
BooleanTest::test_multiple
%endif
EOF
)

export PYTHONPATH="${PWD}/_stub:%{buildroot}%{python3_sitelib}"
%pytest -v -k "${k-}" -n auto


%files -n python3-trimesh
%license LICENSE.md
%doc README.md
# %%pyproject_save_files cannot handle skipping byte-compilation for
# blender_boolean.py, so we list files manually:
%{python3_sitelib}/trimesh
%{python3_sitelib}/trimesh-%{version}.dist-info


%changelog
## START: Generated by rpmautospec
* Mon Sep 02 2024 Packit <hello@packit.dev> - 4.4.8-1
- Update to 4.4.8 upstream release
- Resolves: rhbz#2309131
- Patch out fast-simplification dependency from the recommend extra for
  now, until it can be packaged

* Mon Aug 26 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 4.4.7-5
- Reapply "Temporarily disable blender support on F41 (close RHBZ#2291957)"

* Mon Aug 26 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 4.4.7-4
- Revert "Temporarily disable blender support on F41 (close RHBZ#2291957)"

* Wed Aug 21 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 4.4.7-3
- On s390x, revert "Stop skipping Blender boolean tests; regression was
  fixed in 4.4.7"

* Wed Aug 21 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 4.4.7-2
- Stop skipping Blender boolean tests; regression was fixed in 4.4.7

* Wed Aug 21 2024 Packit <hello@packit.dev> - 4.4.7-1
- Update to 4.4.7 upstream release
- Resolves: rhbz#2306490

* Sat Aug 17 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 4.4.6-2
- Skip and report two tests that fail with Blender 4.2.0

* Fri Aug 16 2024 Packit <hello@packit.dev> - 4.4.6-1
- Update to 4.4.6 upstream release
- Resolves: rhbz#2305357

* Wed Aug 07 2024 Packit <hello@packit.dev> - 4.4.4-1
- Update to 4.4.4 upstream release
- Resolves: rhbz#2303555

* Wed Jul 17 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 4.4.3-4
- Make the easy extra metapackage noarch

* Wed Jul 17 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 4.4.3-3
- F41+: Drop conditionals for F40 and let the branches diverge

* Wed Jul 17 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 4.4.3-2
- F41+: Stop patching out python-cascadio from the recommend extra (except
  on s390x)

* Mon Jul 15 2024 Packit <hello@packit.dev> - 4.4.3-1
- Update to 4.4.3 upstream release
- Resolves: rhbz#2297916

* Wed Jul 10 2024 Packit <hello@packit.dev> - 4.4.2-1
- Update to 4.4.2 upstream release
- Resolves: rhbz#2296864

* Thu Jul 04 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 4.4.1-6
- Fix regressions with Pillow 10.4.0

* Tue Jul 02 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 4.4.1-5
- No longer patch out openctm from the extras

* Tue Jul 02 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 4.4.1-4
- Temporarily skip a few regressions with Pillow 10.4.0

* Wed Jun 19 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 4.4.1-2
- Temporarily disable blender support on F41 (close RHBZ#2291957)

* Thu Jun 06 2024 Packit <hello@packit.dev> - 4.4.1-1
- Update to 4.4.1 upstream release
- Resolves: rhbz#2290810

* Tue May 21 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 4.4.0-4
- Stop patching out python-fcl support

* Tue May 21 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 4.4.0-3
- Re-enable Blender support

* Sat May 18 2024 Packit <hello@packit.dev> - 4.4.0-1
- Update to 4.4.0 upstream release
- Resolves: rhbz#2281370

* Tue Apr 30 2024 Packit <hello@packit.dev> - 4.3.2-1
- Update to 4.3.2 upstream release
- Resolves: rhbz#2277907

* Tue Apr 16 2024 Packit <hello@packit.dev> - 4.3.1-1
- Update to 4.3.1 upstream release
- Resolves: rhbz#2275346

* Wed Apr 10 2024 Packit <hello@packit.dev> - 4.3.0-1
- Update to 4.3.0 upstream release
- Resolves: rhbz#2274210

* Sun Mar 31 2024 Packit <hello@packit.dev> - 4.2.4-1
- [packit] 4.2.4 upstream release
- Resolves: rhbz#2272419

* Fri Mar 29 2024 Packit <hello@packit.dev> - 4.2.3-1
- [packit] 4.2.3 upstream release
- Resolves: rhbz#2272243

* Tue Mar 26 2024 Packit <hello@packit.dev> - 4.2.2-1
- [packit] 4.2.2 upstream release
- Resolves: rhbz#2269077

* Tue Mar 26 2024 Packit <hello@packit.dev> - 4.2.1-1
- [packit] 4.2.1 upstream release
- Resolves: rhbz#2269077

* Fri Mar 22 2024 Packit <hello@packit.dev> - 4.2.0-1
- [packit] 4.2.0 upstream release
- Resolves rhbz#2269077

* Thu Mar 07 2024 Packit <hello@packit.dev> - 4.1.8-1
- [packit] 4.1.8 upstream release
- Resolves rhbz#2268510

* Thu Feb 29 2024 Packit <hello@packit.dev> - 4.1.7-1
- [packit] 4.1.7 upstream release
- Resolves rhbz#2267139

* Wed Feb 28 2024 Packit <hello@packit.dev> - 4.1.6-1
- [packit] 4.1.6 upstream release
- Resolves rhbz#2266199

* Fri Feb 23 2024 Packit <hello@packit.dev> - 4.1.5-1
- [packit] 4.1.5 upstream release
- Resolves rhbz#2265757

* Mon Feb 19 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 4.1.4-2
- Drop Pyglet from “recommend” extra in F41 and later
- The python-pyglet package was updated to 2.0.10, and the trimesh viewer
  still requires 1.x.

* Sat Feb 17 2024 Packit <hello@packit.dev> - 4.1.4-1
- [packit] 4.1.4 upstream release
- Resolves rhbz#2262450

* Fri Feb 02 2024 Packit <hello@packit.dev> - 4.1.3-1
- [packit] 4.1.3 upstream release
- Resolves rhbz#2262450

* Fri Feb 02 2024 Packit <hello@packit.dev> - 4.1.2-1
- [packit] 4.1.2 upstream release
- Resolves rhbz#2262358

* Fri Jan 26 2024 Packit <hello@packit.dev> - 4.1.0-1
- [packit] 4.1.0 upstream release
- Resolves rhbz#2260584

* Fri Jan 26 2024 Fedora Release Engineering <releng@fedoraproject.org> - 4.0.10-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Mon Jan 22 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 4.0.10-3
- Disable Blender support in F40 until it can be successfully rebuilt

* Mon Jan 22 2024 Fedora Release Engineering <releng@fedoraproject.org> - 4.0.10-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Wed Jan 17 2024 Packit <hello@packit.dev> - 4.0.10-1
- [packit] 4.0.10 upstream release
- Resolves rhbz#2258892

* Sat Jan 13 2024 Packit <hello@packit.dev> - 4.0.9-1
- [packit] 4.0.9 upstream release
- Resolves rhbz#2257975

* Sat Dec 23 2023 Packit <hello@packit.dev> - 4.0.8-1
- [packit] 4.0.8 upstream release
- Resolves rhbz#2255685

* Tue Dec 19 2023 Packit <hello@packit.dev> - 4.0.7-1
- [packit] 4.0.7 upstream release
- Resolves rhbz#2255301

* Tue Dec 19 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 4.0.6-1
- Update to 4.0.6 (close RHBZ#2255185)

* Thu Nov 23 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 4.0.5-1
- Update to 4.0.5 (close RHBZ#2251121)

* Sat Nov 11 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 4.0.4-1
- Update to 4.0.4 (close RHBZ#2249167)

* Wed Nov 08 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 4.0.3-1
- Update to 4.0.3 (close RHBZ#2248602)

* Tue Oct 31 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 4.0.2-2
- Drop support for i686 (leaf package)

* Tue Oct 31 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 4.0.2-1
- Update to 4.0.2

* Wed Oct 25 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 4.0.1-1
- Update to 4.0.1

* Tue Oct 24 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 4.0.0-1
- Update to 4.0.0 (close RHBZ#2239764)
- The “recommends” extra is renamed to “recommend” and becomes a weak
  dependency
- The “all” extra is dropped and Obsoleted
- Conditionals for older Fedora releases are dropped

* Tue Oct 03 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.23.5-5
- Add a dependency on “dot” from graphviz

* Sun Oct 01 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.23.5-4
- Stop skipping Blender boolean tests

* Tue Aug 29 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.23.5-2
- Fix meshio and glooey not patched out of “recommends” extra

* Thu Aug 24 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.23.5-1
- Update to 3.23.5 (close RHBZ#2234611)

* Fri Aug 18 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.23.3-1
- Update to 3.23.3 (close RHBZ#2232441)

* Sat Aug 05 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.23.0-2
- Re-enable blender tests

* Wed Aug 02 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.23.0-1
- Update to 3.23.0 (close RHBZ#2228288)

* Wed Jul 19 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.22.5-1
- Update to 3.22.5 (close RHBZ#2224096)

* Fri Jul 14 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.22.4-1
- Update to 3.22.4 (close RHBZ#2222806)

* Fri Jul 14 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.22.3-7
- Revert "Disable scikit-image support until it’s ready for Python 3.12"

* Mon Jul 10 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.22.3-6
- Rebuild for Python 3.12 (close RHBZ#2220540)

* Mon Jul 10 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.22.3-5
- Disable scikit-image support until it’s ready for Python 3.12

* Mon Jul 10 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.22.3-4
- Disable Blender support until it’s ready for Python 3.12

* Mon Jul 10 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.22.3-3
- Add a build conditional for scikit-image availability

* Mon Jul 10 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.22.3-2
- Add a build conditional for Blender support

* Sat Jul 01 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.22.3-1
- Update to 3.22.3 (close RHBZ#2218965)

* Thu Jun 29 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.22.2-1
- Update to 3.22.2 (close RHBZ#2218416)

* Sat Jun 17 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.22.1-1
- Update to 3.22.1 (close RHBZ#2215371)
- Work around new test dependency on python-pymeshlab, not packaged

* Tue Jun 06 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.22.0-2
- Upload missing source file

* Tue Jun 06 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.22.0-1
- Update to 3.22.0 (close RHBZ#2212601)

* Sun May 21 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.21.7-2
- Update to 3.21.7 (close RHBZ#2208624)

* Sat May 20 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.21.7-1
- Update to 3.21.7 (close RHBZ#2208624)

* Mon May 08 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.21.6-1
- Update to 3.21.6 (close RHBZ#2196070)

* Tue Apr 11 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.21.5-1
- Update to 3.21.5 (close RHBZ#2185978)

* Fri Apr 07 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.21.4-4
- Skip a new big-endian failure

* Fri Apr 07 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.21.4-3
- Skip a couple of tests with Blender 3.5.0 regressions

* Thu Apr 06 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.21.4-2
- Skip a new 32-bit failure

* Thu Apr 06 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.21.4-1
- Update to 3.21.4 (close RHBZ#2181682)

* Wed Mar 22 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.21.0-1
- Update to 3.21.0 (close RHBZ#2180554)

* Thu Mar 09 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.20.2-2
- Revert "Work around Blender FTBFS/FTI bug in F38/F39"

* Wed Mar 08 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.20.2-1
- Update to 3.20.2 (close RHBZ#2176618)

* Fri Feb 24 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.20.1-1
- Update to 3.20.1 (close RHBZ#2173108)

* Fri Feb 24 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.20.0-4
- Work around Blender FTBFS/FTI bug in F38/F39

* Mon Feb 20 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.20.0-3
- Reference upstream bug for V-HACD 4.0 support

* Wed Feb 15 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.20.0-2
- Skip flaky test IdentifierTest::test_identifier

* Tue Feb 14 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.20.0-1
- Update to 3.20.0 (close RHBZ#2169873)

* Fri Feb 10 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.19.3-1
- Update to 3.19.3 (close RHBZ#2168757)

* Mon Feb 06 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.18.3-2
- Add BR’s/Recommends on CLI tools that enable functionality

* Wed Feb 01 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.18.3-1
- Update to 3.18.3 (close RHBZ#2166465)

* Tue Jan 31 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.18.2-1
- Update to 3.18.2 (close RHBZ#2166126)

* Tue Jan 31 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.18.1-3
- Run tests in parallel

* Fri Jan 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 3.18.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Tue Jan 17 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.18.1-1
- Update to 3.18.1 (close RHBZ#2161430)

* Wed Jan 11 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.18.0-1
- Update to 3.18.0 (close RHBZ#2159904)

* Fri Dec 02 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.17.1-1
- Update to 3.17.1 (close RHBZ#2150384)

* Thu Dec 01 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.17.0-2
- Skip a new 32-bit test failure

* Thu Dec 01 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.17.0-1
- Update to 3.17.0 (close RHBZ#2150113)

* Thu Nov 17 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.16.4-1
- Update to 3.16.4 (close RHBZ#2143778)

* Wed Nov 16 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.16.3-1
- Update to 3.16.3 (close RHBZ#2143124)

* Mon Nov 14 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.16.2-1
- Update to 3.16.2 (close RHBZ#2141880)

* Thu Nov 10 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.16.1-1
- Update to 3.16.1 (close RHBZ#2140244)

* Sat Oct 29 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.15.8-1
- Update to 3.15.8 (close RHBZ#2137692)

* Fri Oct 14 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.15.5-1
- Update to 3.15.5 (close RHBZ#2133939)

* Thu Oct 06 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.15.3-1
- Update to 3.15.3 (close RHBZ#2131810)

* Thu Sep 22 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.15.2-1
- Update to 3.15.2 (close RHBZ#2129188)

* Sat Sep 17 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.15.1-1
- Update to 3.15.1 (close RHBZ#2127530)
- No longer have to patch out triangle dep.; it was removed upstream

* Sun Sep 04 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.14.1-1
- Update to 3.14.1 (close RHBZ#2123861)

* Tue Aug 23 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.14.0-1
- Update to 3.14.0 (close RHBZ#2120444)

* Thu Aug 18 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.13.5-1
- Update to 3.13.5 (close RHBZ#2119211)

* Fri Aug 12 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.13.4-1
- Update to 3.13.4 (close RHBZ#2117782)

* Thu Aug 11 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.13.1-2
- Skip a new test failure on 32-bit architectures

* Thu Aug 11 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.13.1-1
- Update to 3.13.1 (close RHBZ#2115510)

* Thu Aug 11 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.12.9-3
- Update License to SPDX

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 3.12.9-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Mon Jul 18 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.12.9-1
- Update to 3.12.9 (close RHBZ#2103265)

* Tue Jun 28 2022 Python Maint <python-maint@redhat.com> - 3.12.6-3
- Rebuilt for Python 3.11

* Sat Jun 11 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.12.6-2
- Update spec file comments about missing optional dependencies

* Fri Jun 10 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.12.6-1
- Update to 3.12.6 (close RHBZ#2095121)

* Mon May 30 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.12.5-1
- Update to 3.12.5 (close RHBZ#2088632)

* Thu May 19 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.12.1-1
- Update to 3.12.1 (close RHBZ#2088191)

* Sat May 14 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.12.0-1
- Update to 3.12.0 (close RHBZ#2082701)

* Mon May 02 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.11.2-3
- Revert "F37+: Exclude ix86 and stop tracking 32-bit problems (close
  RHBZ#2006452)"

* Mon May 02 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.11.2-2
- F37+: Exclude ix86 and stop tracking 32-bit problems (close RHBZ#2006452)

* Sun May 01 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.11.2-1
- Update to 3.11.2 (close RHBZ#2079076)

* Tue Apr 12 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.10.8-2
- Stop using “private” macro %%%%_pyproject_ghost_distinfo

* Fri Apr 08 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.10.8-1
- Update to 3.10.8 (close RHBZ#2073136)

* Fri Mar 25 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.10.7-1
- Update to 3.10.7 (close RHBZ#2068305)

* Fri Mar 25 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.10.5-2
- Remove workaround for RHBZ#2006090

* Fri Mar 18 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.10.5-1
- Update to 3.10.5 (close RHBZ#2064832)

* Fri Mar 04 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.10.2-1
- Update to 3.10.2 (fix RHBZ#2057598); stop patching out ezdxf

* Wed Feb 09 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.10.0-1
- Update to 3.10.0 (close RHBZ#2046501)

* Wed Feb 09 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.9.43-1
- Update to 3.9.43 “fix build”

* Wed Feb 09 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.9.42-4
- Remove python-Rtree/spatialite workaround

* Thu Feb 03 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.9.42-3
- Restore mapbox-earcut dependency in “all” extra

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 3.9.42-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Sun Jan 09 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.9.42-1
- Update to 3.9.42 (close RHBZ#2037892)

* Thu Jan 06 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.9.40-1
- Update to 3.9.40 (close RHBZ#2037118)

* Tue Jan 04 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.9.39-1
- Update to 3.9.39 (close RHBZ#2036543)

* Tue Jan 04 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.9.36-2
- Fix missing %%%%autorelease

* Fri Dec 10 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 3.9.36-1
- Update to 3.9.36 (close RHBZ#2030500)

* Thu Dec 09 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 3.9.35-3
- Add link to python-vecrec review request

* Fri Oct 29 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 3.9.35-1
- Update to 3.9.35 (close RHBZ#2018572)

* Wed Oct 20 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 3.9.34-1
- Update to 3.9.34
- Use pyproject-rpm-macros
- Update metapackages for PythonExtras Change
  (https://fedoraproject.org/wiki/Changes/PythonExtras#Extras_metapackages)
- [easy] and [all] extras now require python3dist(xxhash)
- Handle arch-specific test failures methodically
- Update/correct license from “MIT” to “MIT and BSD and zlib”

* Tue Jul 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 3.9.20-3
- Second attempt - Rebuilt for
  https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Sat Jun 26 2021 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 3.9.20-2
- Fix build: omit tests on 32 bit architectures

* Thu Jun 17 2021 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 3.9.20-1
- Update to latest release

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 3.8.17-3
- Rebuilt for Python 3.10

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 3.8.17-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Sat Dec 05 2020 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 3.8.17-1
- Update to latest patch release

* Thu Oct 01 2020 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 3.8.10-1
- Update to latest release

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 3.6.34-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue May 26 2020 Miro Hrončok <mhroncok@redhat.com> - 3.6.34-2
- Rebuilt for Python 3.9

* Fri May 01 2020 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 3.6.34-1
- Update to latest release

* Fri Feb 21 2020 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 3.5.23-2
- Temporarily disable tests that fail on 32 bit builders
- https://github.com/mikedh/trimesh/issues/690

* Fri Feb 21 2020 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 3.5.23-1
- Update to latest release

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 2.37.12-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Tue Oct 29 2019 Miro Hrončok <mhroncok@redhat.com> - 2.37.12-5
- Drop weak dependencies on packages not available in Fedora

* Thu Oct 03 2019 Miro Hrončok <mhroncok@redhat.com> - 2.37.12-4
- Rebuilt for Python 3.8.0rc1 (#1748018)

* Mon Aug 19 2019 Miro Hrončok <mhroncok@redhat.com> - 2.37.12-3
- Rebuilt for Python 3.8

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.37.12-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Sat Mar 16 2019 Miro Hrončok <mhroncok@redhat.com> - 2.37.12-1
- Update to 2.37.12 (#1678964)

* Mon Feb 18 2019 Lumír Balhar <lbalhar@redhat.com> - 2.36.29-1
- Update to 2.36.29 (#1678054)

* Sat Feb 16 2019 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 2.36.28-1
- Update to 2.36.28 (#1677725)

* Sun Feb 10 2019 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 2.36.24-1
- Update to 2.36.24 (#1668080)

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.36.13-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Mon Jan 21 2019 Miro Hrončok <mhroncok@redhat.com> - 2.36.13-1
- Update to 2.36.13 (#1667470)

* Fri Nov 09 2018 Miro Hrončok <mhroncok@redhat.com> - 2.35.24-1
- Update to 2.35.24 (#1648477)

* Mon Sep 03 2018 Miro Hrončok <mhroncok@redhat.com> - 2.33.12-1
- Update to 2.33.12

* Mon Sep 03 2018 Miro Hrončok <mhroncok@redhat.com> - 2.33.11-1
- Initial package

## END: Generated by rpmautospec
